import { LuciaError } from "../error.js";
import cookie from "cookie";
export const parseRequestFunction = (auth) => {
    const parseRequest = (request) => {
        const cookies = cookie.parse(request.headers.get("cookie") || "");
        const sessionId = cookies.auth_session || "";
        const checkForCsrf = request.method !== "GET" && request.method !== "HEAD";
        if (checkForCsrf && auth.configs.csrfProtection) {
            const origin = request.headers.get("Origin");
            const url = new URL(request.url);
            if (!origin)
                throw new LuciaError("AUTH_INVALID_REQUEST");
            if (url.origin !== origin)
                throw new LuciaError("AUTH_INVALID_REQUEST");
        }
        return sessionId;
    };
    return parseRequest;
};
export const validateRequestFunction = (auth) => {
    const validateRequest = async (request) => {
        const sessionId = auth.parseRequest(request);
        try {
            const session = await auth.validateSession(sessionId);
            return session;
        }
        catch (e) {
            if (e instanceof LuciaError) {
                const renewedSession = await auth.renewSession(sessionId);
                await auth.deleteDeadUserSessions(renewedSession.userId);
                return renewedSession;
            }
            throw e;
        }
    };
    return validateRequest;
};
